@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2006 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,9 +22,13 @@
 # Ported from Perl's Image::Size module by Randy J. Ray
 #
 
-import os, os.path, re, struct
-
+# Std Lib
+import os
+import os.path
+import re
+import struct
 
+# Re patterns
 xbm_pat = re.compile(r'^\#define\s*\S*\s*(\d+)\s*\n\#define\s*\S*\s*(\d+)', re.IGNORECASE)
 xpm_pat = re.compile(r'"\s*(\d+)\s+(\d+)(\s+\d+\s+\d+){1,2}\s*"', re.IGNORECASE)
 ppm_pat1 = re.compile(r'^\#.*', re.IGNORECASE | re.MULTILINE)
@@ -33,7 +37,6 @@ ppm_pat3 = re.compile(r'IMGINFO:(\d+)x(\d+)', re.IGNORECASE)
 tiff_endian_pat = re.compile(r'II\x2a\x00')
 
 
-
 def readin(stream, length, offset=0):
     if offset != 0:
         stream.seek(offset, 0)
@@ -192,7 +195,7 @@ TYPE_MAP = {re.compile('^GIF8[7,9]a')              : ('image/gif', gifsize),
 def imagesize(filename, mime_type=''):
     width, height = -1, -1
 
-    f = file(filename, 'r')
+    f = open(filename, 'r')
     buffer = f.read(4096)
 
     if not mime_type:
@@ -211,4 +214,4 @@ def imagesize(filename, mime_type=''):
     f.close()
 
     return height, width, mime_type
-    
+
