@@ -41,7 +41,7 @@ from prnt import cups
 
 def CleanUIx(level):
     global d
-    ok = tui.continue_prompt("Ready to perform level %d cleaning (Note: Wait for previous print to finish)." % level)
+    ok = tui.continue_prompt("Ready to perform level %d cleaning ." % level)
 
     if ok:
         timeout = 0
@@ -74,20 +74,33 @@ def CleanUIx(level):
 
     return ok
 
-def CleanUI1():
-    log.note("Please wait for page to complete printing before continuing.")
-    log.info("\nLevel 1 cleaning complete. If the printout looks OK, enter 'q' to quit or <enter> to do a level 2 cleaning.")
+def CleanUI1(msg=""):
+    if not msg:
+        log.note("Please wait for page to complete printing before continuing.\nLevel 1 cleaning complete. If the printout looks OK.")
+        log.info("Note: Wait for previous print to finish") 
+    else:
+        log.note(msg)
+
+    log.info("Press enter 'q' to quit or <enter> to do a level 2 cleaning.")
     return CleanUIx(2)
 
 
-def CleanUI2():
-    log.note("Please wait for page to complete printing before continuing.")
-    log.info("\nLevel 2 cleaning complete. If the printout looks OK, enter 'q' to quit or <enter> to do a level 3 cleaning.")
+def CleanUI2(msg=""):
+    if not msg:
+        log.note("Please wait for page to complete printing before continuing.\nLevel 2 cleaning complete. If the printout looks OK.")
+        log.info("Note: Wait for previous print to finish") 
+    else:
+        log.note(msg)
+
+    log.info("Press enter 'q' to quit or <enter> to do a level 3 cleaning.")
     log.warn("Level 3 uses a lot of ink.")
     return CleanUIx(3)
 
-def CleanUI3():
-    log.info("\nLevel 3 cleaning complete. Check this page to see if the problem was fixed. If the test page was not printed OK, replace the print cartridge(s).")
+def CleanUI3(msg =""):
+    if msg:
+        log.info(msg)
+    else:
+        log.info("\nLevel 3 cleaning complete. Check this page to see if the problem was fixed. If the test page was not printed OK, replace the print cartridge(s).")
 
 
 try:
@@ -104,6 +117,9 @@ try:
     device_uri = mod.getDeviceUri(device_uri, printer_name,
        filter={'clean-type': (operator.ne, CLEAN_TYPE_NONE)})
 
+    if not device_uri:
+        sys.exit(1)
+
     if mode == GUI_MODE:
         if not utils.canEnterGUIMode4():
             log.error("%s -u/--gui requires Qt4 GUI support. Entering interactive mode." % __mod__)
@@ -112,7 +128,7 @@ try:
     if mode == INTERACTIVE_MODE:
         try:
             d = device.Device(device_uri, printer_name)
-        except Error, e:
+        except Error as e:
             log.error("Unable to open device: %s" % e.msg)
             sys.exit(0)
 
@@ -150,10 +166,16 @@ try:
                                         CleanUI1, CleanUI2, CleanUI3,
                                         None)
 
+                    elif clean_type == CLEAN_TYPE_LEDM:
+                        maint.cleaning(d, clean_type, maint.cleanTypeLedm, maint.cleanTypeLedm1,
+                                        maint.cleanTypeLedm2, tui.load_paper_prompt,
+                                        CleanUI1, CleanUI2, CleanUI3,
+                                        None, maint.isCleanTypeLedmWithPrint)
+
                     else:
                         log.error("Cleaning not needed or supported on this device.")
 
-                except Error, e:
+                except Error as e:
                     log.error("An error occured: %s" % e[0])
 
             else:
@@ -174,7 +196,6 @@ try:
         #try:
         if 1:
             app = QApplication(sys.argv)
-
             dlg = CleanDialog(None, device_uri)
             dlg.show()
             try:
