@@ -209,13 +209,15 @@ int  __attribute__ ((visibility ("hidden"))) generalize_serial(const char *sz, c
 int __attribute__ ((visibility ("hidden"))) get_uri_model(const char *uri, char *buf, int bufSize);
 int __attribute__ ((visibility ("hidden"))) get_uri_serial(const char *uri, char *buf, int bufSize);
 enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) service_to_channel(mud_device *pd, const char *sn, HPMUD_CHANNEL *index);
-int (*getSIData)(char **pData , int *pDataLen, char **pModeSwitch, int *pModeSwitchLen);
-void (*freeSIData)(char *pData, char *pModeSwitch);
+extern int (*getSIData)(char **pData , int *pDataLen, char **pModeSwitch, int *pModeSwitchLen);
+extern void (*freeSIData)(char *pData, char *pModeSwitch);
 
 static const char *SnmpPort[] = { "","public","public.1","public.2","public.3"};
+
 #define PORT_PUBLIC  1
 #define PORT_PUBLIC_1  2
 #define PORT_PUBLIC_2  3
 #define PORT_PUBLIC_3  4
+
 #endif // _HPMUDI_H
 
