@@ -79,9 +79,15 @@ Yashwant Kumar Sahu
 #include <cups/cups.h>
 #include <cups/language.h>
 #include <cups/ppd.h>
+#include <syslog.h>
+#include <stdarg.h>
 #include <sys/types.h>
 #include <pwd.h>
 
+
+#include "cupsext.h"
+
+
 /* Ref: PEP 353 (Python 2.5) */
 #if PY_VERSION_HEX < 0x02050000
 typedef int Py_ssize_t;
@@ -89,6 +95,10 @@ typedef int Py_ssize_t;
 #define PY_SSIZE_T_MIN INT_MIN
 #endif
 
+#define _STRINGIZE(x) #x
+#define STRINGIZE(x) _STRINGIZE(x)
+
+
 #if (CUPS_VERSION_MAJOR > 1) || (CUPS_VERSION_MINOR > 5)
     #define HAVE_CUPS_1_6 1
 #endif
@@ -215,7 +225,8 @@ static PyObject * PyObj_from_UTF8(const char *utf8)
         }
 
         ascii[i] = '\0';
-        val = PyString_FromString( ascii );
+        //val = PyString_FromString( ascii );
+        val = PYUnicode_STRING( ascii );
         free( ascii );
     }
 
@@ -230,7 +241,8 @@ void debug(const char * text)
 
 }
 
-staticforward PyTypeObject printer_Type;
+//staticforward PyTypeObject printer_Type;
+static PyTypeObject printer_Type;
 
 #define printerObject_Check(v) ((v)->ob_type == &printer_Type)
 
@@ -277,8 +289,10 @@ static PyMemberDef printer_members[] =
 
 static PyTypeObject printer_Type =
 {
-    PyObject_HEAD_INIT( &PyType_Type )
-    0,                                     /* ob_size */
+    /* PyObject_HEAD_INIT( &PyType_Type ) */
+    /* 0, */
+    /*                                  /\* ob_size *\/ */
+    PyVarObject_HEAD_INIT( &PyType_Type, 0 )
     "cupsext.Printer",                   /* tp_name */
     sizeof( printer_Object ),              /* tp_basicsize */
     0,                                     /* tp_itemsize */
@@ -937,8 +951,8 @@ abort:
 
 
 
-staticforward PyTypeObject job_Type;
-
+//staticforward PyTypeObject job_Type;
+static PyTypeObject job_Type;
 typedef struct
 {
     PyObject_HEAD
@@ -977,8 +991,9 @@ static PyMemberDef job_members[] =
 
 static PyTypeObject job_Type =
 {
-    PyObject_HEAD_INIT( &PyType_Type )
-    0,                                     /* ob_size */
+    /* PyObject_HEAD_INIT( &PyType_Type ) */
+    /* 0,                                     /\* ob_size *\/ */
+    PyVarObject_HEAD_INIT( &PyType_Type, 0 )
     "Job",                                 /* tp_name */
     sizeof( job_Object ),                  /* tp_basicsize */
     0,                                     /* tp_itemsize */
@@ -1876,8 +1891,8 @@ const char * password_callback(const char * prompt)
         usernameObj = PyTuple_GetItem(result, 0);
         if (!usernameObj)
             return "";
-        username = PyString_AsString(usernameObj);
-        // printf("usernameObj=%p, username='%s'\n", usernameObj, username); 
+        username = PYUnicode_UNICODE(usernameObj);
+        /*      printf("usernameObj=%p, username='%s'\n", usernameObj, username); */
         if (!username)
             return "";
 
@@ -1886,8 +1901,8 @@ const char * password_callback(const char * prompt)
         passwordObj = PyTuple_GetItem(result, 1);
         if (!passwordObj)
             return "";
-        password = PyString_AsString(passwordObj);
-        // printf("passwrdObj=%p, passwrd='%s'\n", passwordObj, password); 
+        password = PYUnicode_UNICODE(passwordObj);
+        /*      printf("passwordObj=%p, password='%s'\n", passwordObj, password); */
         if (!password)
             return "";
 
@@ -2001,17 +2016,26 @@ static PyMethodDef cupsext_methods[] =
 
 static char cupsext_documentation[] = "Python extension for CUPS 1.x";
 
-void initcupsext( void )
-{
+/* void initcupsext( void ) */
+/* { */
 
-    PyObject * mod = Py_InitModule4( "cupsext", cupsext_methods,
-                                     cupsext_documentation, ( PyObject* ) NULL,
-                                     PYTHON_API_VERSION );
+/*     PyObject * mod = Py_InitModule4( "cupsext", cupsext_methods, */
+/*                                      cupsext_documentation, ( PyObject* ) NULL, */
+/*                                      PYTHON_API_VERSION ); */
 
-    if ( mod == NULL )
-        return ;
+/*     if ( mod == NULL ) */
+/*         return ; */
+/* } */
 
 
+MOD_INIT(cupsext)  {
+
+  PyObject* mod ;
+  MOD_DEF(mod, "cupsext", cupsext_documentation, cupsext_methods);
+  if (mod == NULL)
+    return MOD_ERROR_VAL;
+
+  return MOD_SUCCESS_VAL(mod);
+
 }
 
-
