@@ -56,9 +56,11 @@
 #endif
 
 #define BASIC_LOG          1
-#define SAVE_PCL_FILE      2
+#define SAVE_OUT_FILE      2
 #define SAVE_INPUT_RASTERS 4
-#define SEND_TO_PRINTER_ALSO    8
+#define SAVE_OUT_FILE_IN_BACKEND    8
+#define DONT_SEND_TO_BACKEND   16
+#define DONT_SEND_TO_PRINTER   32
 
 #define MAX_COLORTYPE 2
 #define NUMBER_PLANES 3
@@ -338,9 +340,9 @@ typedef enum
 #define EVENT_PRINT_FAILED_MISSING_PLUGIN 502
 enum COLORTYPE
 {
-    COLORTYPE_COLOR,       // 0
-    COLORTYPE_BLACK,       // 1
-    COLORTYPE_BOTH
+    COLORTYPE_COLOR     = 0,       
+    COLORTYPE_BLACK     = 1,    
+    COLORTYPE_BOTH      = 2
 };
 
 typedef struct ColorMap_s
@@ -411,6 +413,7 @@ typedef struct QualityAttributes_s
     int             media_type;
     int             media_subtype;
     int             print_quality;
+    char            hbpl1_print_quality[32];
     unsigned int    horizontal_resolution;
     unsigned int    vertical_resolution;
     unsigned int    actual_vertical_resolution;
