@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2009 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,12 +22,14 @@
 # Local
 from base.g import *
 from base import utils, magic
+from base.sixext import  to_unicode
 from pcard import photocard
+from .ui_utils import load_pixmap
 
 # Qt
 from qt import *
-from scrollview import ScrollView, PixmapLabelButton
-from imagepropertiesdlg import ImagePropertiesDlg
+from .scrollview import ScrollView, PixmapLabelButton
+from .imagepropertiesdlg import ImagePropertiesDlg
 #from waitform import WaitForm
 
 # Std Lib
@@ -47,22 +49,22 @@ class IconViewItem(QIconViewItem):
 
 
 class ScrollUnloadView(ScrollView):
-    def __init__(self, toolbox_hosted=True, parent = None, form=None, name = None,fl = 0):
-        ScrollView.__init__(self, parent, name, fl)
-        self.toolbox_hosted = toolbox_hosted
+    def __init__(self, service, parent=None, form=None, name=None, fl=0):
+        ScrollView.__init__(self, service, parent, name, fl)
+
         self.form = form
         self.progress_dlg = None
         self.unload_dir = os.path.normpath(os.path.expanduser('~'))
 
-        self.image_icon_map = {'tiff' : 'tif.png',
-                                'bmp'  : 'bmp.png',
-                                'jpeg' : 'jpg.png',
-                                'gif'  : 'gif.png',
-                                'unknown' : 'unknown.png',
+        self.image_icon_map = {'tiff' : 'tif',
+                               'bmp'  : 'bmp',
+                               'jpeg' : 'jpg',
+                               'gif'  : 'gif',
+                               'unknown' : 'unknown',
                                 }
 
-        self.video_icon_map = {'unknown' : 'movie.png',
-                                'mpeg'    : 'mpg.png',
+        self.video_icon_map = {'unknown' : 'movie',
+                                'mpeg'    : 'mpg',
                                 }
 
         QTimer.singleShot(0, self.fillControls)
@@ -87,18 +89,13 @@ class ScrollUnloadView(ScrollView):
 
         self.addGroupHeading("space1", "")
 
-        if self.toolbox_hosted:
-            s = self.__tr("<< Functions")
-        else:
-            s = self.__tr("Close")
-
-        self.unloadButton = self.addActionButton("bottom_nav", self.__tr("Unload File(s)"), 
-                                self.unloadButton_clicked, 'download-small.png', 'download-small-disabled.png', 
-                                s, self.funcButton_clicked)
+        self.unloadButton = self.addActionButton("bottom_nav", self.__tr("Unload File(s)"),
+                                self.unloadButton_clicked, 'download.png', 'download.png',
+                                self.__tr("Close"), self.funcButton_clicked)
 
         self.unloadButton.setEnabled(False)
 
-        self.maximizeControl()   
+        self.maximizeControl()
 
 
     def onDeviceChange(self, cur_device=None):
@@ -121,7 +118,7 @@ class ScrollUnloadView(ScrollView):
 
             try:
                 self.pc = photocard.PhotoCard(None, self.cur_device.device_uri, self.cur_printer)
-            except Error, e:
+            except Error as e:
                 QApplication.restoreOverrideCursor()
                 self.form.FailureUI(self.__tr("An error occured: %s" % e[0]))
                 self.cleanup(EVENT_PCARD_UNABLE_TO_MOUNT)
@@ -150,9 +147,10 @@ class ScrollUnloadView(ScrollView):
                     return
 
                 self.device_uri = self.pc.device.device_uri
-                user_cfg.last_used.device_uri = self.device_uri
+                user_conf.set('last_used', 'device_uri', self.device_uri)
 
-                self.pc.device.sendEvent(EVENT_START_PCARD_JOB)
+                # TODO:
+                #self.pc.device.sendEvent(EVENT_START_PCARD_JOB)
 
                 disk_info = self.pc.info()
                 self.pc.write_protect = disk_info[8]
@@ -165,10 +163,7 @@ class ScrollUnloadView(ScrollView):
                 if not self.pc.write_protect:
                     log.info("DO NOT REMOVE PHOTO CARD UNTIL YOU EXIT THIS PROGRAM")
 
-                if user_cfg.last_used.working_dir and \
-                    os.path.exists(user_cfg.last_used.working_dir):
-
-                    self.unload_dir = user_cfg.last_used.working_dir
+                self.unload_dir = user_conf.workingDirectory()
 
                 try:
                     os.chdir(self.unload_dir)
@@ -220,7 +215,7 @@ class ScrollUnloadView(ScrollView):
         spacer34 = QSpacerItem(20,20,QSizePolicy.Expanding,QSizePolicy.Minimum)
         layout32.addItem(spacer34,2,2)
 
-        self.selectAllPushButton = PixmapLabelButton(widget, 'ok_small.png', None)
+        self.selectAllPushButton = PixmapLabelButton(widget, 'ok.png', None)
 
         layout32.addWidget(self.selectAllPushButton,2,0)
 
@@ -435,13 +430,16 @@ class ScrollUnloadView(ScrollView):
 
         elif self.first_load:
             if typ == 'image':
-                f = os.path.join(prop.image_dir, self.image_icon_map.get(subtyp, 'unknown.png'))
+                f = self.image_icon_map.get(subtyp, 'unknown')
+
             elif typ == 'video':
-                f = os.path.join(prop.image_dir, self.video_icon_map.get(subtyp, 'movie.png'))
+                f = self.video_icon_map.get(subtyp, 'movie')
+
             elif typ == 'audio':
-                f = os.path.join(prop.image_dir, 'sound.png')
+                f = 'sound'
+
             else:
-                f = os.path.join(prop.image_dir, 'unknown.png')
+                f = 'unknown'
 
             dirname, fname=os.path.split(path)
             num = 1
@@ -454,11 +452,11 @@ class ScrollUnloadView(ScrollView):
                 num = len(self.item_map[fname])
 
             if num == 1:
-                IconViewItem(self.IconView, dirname, fname, path, QPixmap(f),
-                              typ, subtyp, size)
+                IconViewItem(self.IconView, dirname, fname, path,
+                    load_pixmap(f, '128x128'), typ, subtyp, size)
             else:
                 IconViewItem(self.IconView, dirname, fname + " (%d)" % num,
-                              path, QPixmap(f), typ, subtyp, size)
+                              path,load_pixmap(f, '128x128'), typ, subtyp, size)
 
     def resizePixmap(self, pixmap):
         w, h = pixmap.width(), pixmap.height()
@@ -482,14 +480,14 @@ class ScrollUnloadView(ScrollView):
 
         self.UnloadDirectoryBrowseButton.setText(self.__tr("Browse..."))
         self.connect(self.UnloadDirectoryBrowseButton,SIGNAL("clicked()"),self.UnloadDirectoryBrowseButton_clicked)
-        self.connect(self.UnloadDirectoryEdit,SIGNAL("textChanged(const QString&)"),self.UnloadDirectoryEdit_textChanged)        
+        self.connect(self.UnloadDirectoryEdit,SIGNAL("textChanged(const QString&)"),self.UnloadDirectoryEdit_textChanged)
 
         self.bg = self.UnloadDirectoryEdit.paletteBackgroundColor()
 
         self.addWidget(widget, "folder")
 
     def UnloadDirectoryEdit_textChanged(self, dir):
-        self.unload_dir = unicode(dir)
+        self.unload_dir = to_unicode(dir)
 
         if not os.path.exists(self.unload_dir):
             self.UnloadDirectoryEdit.setPaletteBackgroundColor(QColor(0xff, 0x99, 0x99))
@@ -498,7 +496,7 @@ class ScrollUnloadView(ScrollView):
 
     def UnloadDirectoryBrowseButton_clicked(self):
         old_dir = self.unload_dir
-        self.unload_dir = unicode(QFileDialog.getExistingDirectory(self.unload_dir, self))
+        self.unload_dir = to_unicode(QFileDialog.getExistingDirectory(self.unload_dir, self))
 
         if not len(self.unload_dir):
             return
@@ -510,7 +508,7 @@ class ScrollUnloadView(ScrollView):
         else:
             self.UnloadDirectoryEdit.setText(self.unload_dir)
             os.chdir(self.unload_dir)
-            user_cfg.last_used.working_dir = self.unload_dir.encode('utf-8')
+            user_conf.setWorkingDirectory(self.unload_dir)
 
     def addOptions(self):
         widget = self.getWidget()
@@ -543,7 +541,7 @@ class ScrollUnloadView(ScrollView):
         was_cancelled = False
         self.busy = True
         self.unloadButton.setEnabled(False)
-        self.unload_dir = unicode(self.UnloadDirectoryEdit.text())
+        self.unload_dir = to_unicode(self.UnloadDirectoryEdit.text())
         dir_error = False
 
         try:
@@ -595,7 +593,8 @@ class ScrollUnloadView(ScrollView):
             self.progress_dlg.close()
             self.progress_dlg = None
 
-            self.pc.device.sendEvent(EVENT_PCARD_FILES_TRANSFERED)
+            # TODO:
+            #self.pc.device.sendEvent(EVENT_PCARD_FILES_TRANSFERED)
 
             if self.removal_option != 0: # remove selected or remove all
                 self.unload_list = self.pc.get_unload_list()
@@ -629,7 +628,9 @@ class ScrollUnloadView(ScrollView):
     def cleanup(self, error=0):
         if self.pc is not None:
             if error > 0:
-                self.pc.device.sendEvent(error, typ='error')
+                # TODO:
+                #self.pc.device.sendEvent(error, typ='error')
+                pass
 
             try:
                 self.pc.umount()
@@ -641,11 +642,8 @@ class ScrollUnloadView(ScrollView):
         if self.pc is not None:
             self.pc.umount()
             self.pc.device.close()
-        
-        if self.toolbox_hosted:
-            self.form.SwitchFunctionsTab("funcs")
-        else:
-            self.form.close()
+
+        self.form.close()
 
     def __tr(self,s,c = None):
         return qApp.translate("ScrollUnloadView",s,c)
