@@ -21,9 +21,10 @@
 
 from base.g import *
 from base.codes import *
+from base.sixext import  to_unicode
 
 from qt import *
-from setupsettings_base import SetupSettings_base
+from .setupsettings_base import SetupSettings_base
 
 class SetupSettings(SetupSettings_base):
     def __init__(self, bus, filter, search, ttl, timeout, parent=None, name=None, modal=0, fl = 0):
@@ -34,14 +35,18 @@ class SetupSettings(SetupSettings_base):
         self.ttl = ttl
         self.timeout = timeout
 
-        if 'none' in filter:
-            self.filterButtonGroup.setButton(0)
+        log.debug("filter is %s" % filter)
+        if prop.fax_build and prop.scan_build:
+            if not filter:
+                self.filterButtonGroup.setButton(0)
+            else:
+                self.filterButtonGroup.setButton(1)
+                self.faxCheckBox.setChecked('fax' in filter)
+                self.scanCheckBox.setChecked('scan' in filter)
+                self.pcardCheckBox.setChecked('pcard' in filter)
+                self.copyCheckBox.setChecked('copy' in filter)
         else:
-            self.filterButtonGroup.setButton(1)
-            self.faxCheckBox.setChecked('fax' in filter)
-            self.scanCheckBox.setChecked('scan' in filter)
-            self.pcardCheckBox.setChecked('pcard' in filter)
-            self.copyCheckBox.setChecked('copy' in filter)
+            self.filterButtonGroup.setEnabled(False)
 
         self.searchTermLineEdit.setText(self.search)
 
@@ -71,7 +76,7 @@ class SetupSettings(SetupSettings_base):
         self.updateFilter(a0)
 
     def searchTermLineEdit_textChanged(self, a0):
-        self.search = unicode(a0)
+        self.search = to_unicode(a0)
 
     def ttlSpinBox_valueChanged(self, a0):
         self.ttl = a0
@@ -82,28 +87,26 @@ class SetupSettings(SetupSettings_base):
         log.debug(self.timeout)
 
     def updateFilter(self, id=-1):
+        self.filter = []
+        
         if id == 0:
-            self.filter = 'none'
+            return 
 
         else:
-            filters = []
-
             if self.faxCheckBox.isChecked():
-                filters.append('fax')
+                self.filter.append('fax')
 
             if self.scanCheckBox.isChecked():
-                filters.append('scan')
+                self.filter.append('scan')
 
             if self.pcardCheckBox.isChecked():
-                filters.append('pcard')
+                self.filter.append('pcard')
 
             if self.copyCheckBox.isChecked():
-                filters.append('copy')
+                self.filter.append('copy')
 
-            if not filters:
-                filters.append('none')
-
-            self.filter = ','.join(filters)
+            #if not filter:
+            #    filter.append('none')
 
         log.debug(self.filter)
 
