@@ -21,7 +21,7 @@
 
 import sys
 from qt import *
-from waitform_base import WaitForm_base
+from .waitform_base import WaitForm_base
 
 class WaitForm(WaitForm_base):
     def __init__(self, seconds, message=None, cancel_func=None, parent=None, name=None, modal=0, fl=0):
@@ -55,6 +55,7 @@ class WaitForm(WaitForm_base):
 
     def setMessage(self, message):
         self.textLabel3.setText(message)
+        qApp.processEvents()
 
     def cancelPushButton_clicked(self):
         self.canceled = True
